@@ -23,8 +23,8 @@ Description:
 CVS Information:
  
     $Source: /home/globdev/CVS/globus-packages/gatekeeper/source/globus_gatekeeper.c,v $
-    $Date: 2008/08/15 09:09:53 $
-    $Revision: 1.94.2.2 $
+    $Date: 2010/03/09 15:06:24 $
+    $Revision: 1.97.2.2 $
     $Author: bester $
 
  This source file has been modified by Brent Milne (BMilne@lbl.gov)
@@ -85,7 +85,9 @@ CVS Information:
 #include <termios.h>
 #endif
 
-#if defined(TARGET_ARCH_AIX)
+#if defined(HAVE_SOCKLEN_T)
+#define netlen_t socklen_t
+#elif defined(TARGET_ARCH_AIX)
 #define netlen_t size_t
 #else
 #define netlen_t int
@@ -246,7 +248,6 @@ static char *   service_name = NULL;
 static char *   grid_services = "etc/grid-services";
 static char *   gridmap = "etc/gridmap";
 static char *   globuskmap = "etc/globuskmap";
-static char *   globuspwd = NULL;
 static char *   globuscertdir = "cert";
 static char *   globuskeydir = "key";
 static char *   globusnologin ="globus-nologin";
@@ -798,12 +799,6 @@ main(int xargc,
             gridmap = argv[i+1];
             i++;
         }
-        else if ((strcmp(argv[i], "-globuspwd") == 0)
-                 && (i + 1 < argc))
-        {
-            globuspwd = argv[i+1];
-            i++;
-        }
         else if ((strcmp(argv[i], "-globuskeydir") == 0)
                  && (i + 1 < argc))
         {
@@ -916,7 +911,7 @@ main(int xargc,
                     "[-home path] [-l[ogfile] logfile] [-acctfile acctfile] [-e path] ",
                     "[-launch_method fork_and_exit|fork_and_wait|dont_fork] "
                     "[-grid_services file] ",
-                    "[-globusid globusid] [-gridmap file] [-globuspwd file]",
+                    "[-globusid globusid] [-gridmap file] ",
                     "[-x509_cert_dir path] [-x509_cert_file file]",
                     "[-x509_user_cert file] [-x509_user_key file]",
                     "[-x509_user_proxy file]",
@@ -970,10 +965,6 @@ main(int xargc,
     }
         
     setenv("GRIDMAP", genfilename(gatekeeperhome,gridmap,NULL),1);
-    if (globuspwd) 
-    {
-        setenv("GLOBUSPWD", genfilename(gatekeeperhome,globuspwd,NULL),1);
-    }
 
     if (x509_cert_dir)
     {
@@ -1099,21 +1090,26 @@ main(int xargc,
     }
 
     {
-        char hostname[255];
+        char hostname[255] = "";
         char *globusid;
         struct hostent *hp;
         char *fqdn;
         char * contact_string;
       
-        gethostname(hostname, sizeof(hostname)-1);
-      
-        if ((hp = gethostbyname(hostname)))
+        fqdn = getenv("GLOBUS_HOSTNAME");
+
+        if (fqdn == NULL)
         {
-            fqdn = (char *) hp->h_name;
-        }
-        else
-        {
-            fqdn = (hostname ? hostname : "HOSTNAME");
+            gethostname(hostname, sizeof(hostname)-1);
+          
+            if ((hp = gethostbyname(hostname)))
+            {
+                fqdn = (char *) hp->h_name;
+            }
+            else
+            {
+                fqdn = (hostname[0] != 0 ? hostname : "HOSTNAME");
+            }
         }
       
         globusid = get_globusid();
@@ -2499,7 +2495,7 @@ logging_startup(void)
 	     * The messages will be treated like any other system daemon.
 	     */
 	    logging_syslog = 1;
-	    openlog("GRAM gatekeeper", LOG_PID, LOG_DAEMON);
+	    openlog("GRAM-gatekeeper", LOG_PID, LOG_DAEMON);
 	}
 
         if (strlen(logfile) > 0) 
